import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { ArchivesVO, ArchivesForm, ArchivesQuery } from '@/api/archives/types';

/**
 * 查询电子档案列表
 * @param query
 * @returns {*}
 */

export const listArchives = (query?: ArchivesQuery): AxiosPromise<ArchivesVO[]> => {
  return request({
    url: '/filemanager/archives/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询电子档案详细
 * @param id
 */
export const getArchives = (id: string | number): AxiosPromise<ArchivesVO> => {
  return request({
    url: '/filemanager/archives/' + id,
    method: 'get'
  });
};

/**
 * 新增电子档案
 * @param data
 */
export const addArchives = (data: ArchivesForm) => {
  return request({
    url: '/filemanager/archives',
    method: 'post',
    data: data
  });
};

/**
 * 修改电子档案
 * @param data
 */
export const updateArchives = (data: ArchivesForm) => {
  return request({
    url: '/filemanager/archives',
    method: 'put',
    data: data
  });
};

/**
 * 删除电子档案
 * @param id
 */
export const delArchives = (id: string | number | Array<string | number>) => {
  return request({
    url: '/filemanager/archives/' + id,
    method: 'delete'
  });
};

export const getArchive_files = (id: string | number | Array<string | number>) => {
  return request({
    url: `/filemanager/archives/${id}/files`,
    method: 'get'
  });
};

export const saveArchive_files = (id: string | number | Array<string | number>,files:string) => {
  return request({
    url: `/filemanager/archives/save/${id}/${files}`,
    method: 'put'
  });
};
