import request from '@/utils/request';
import { OssQuery, OssVO } from './types';
import { AxiosPromise } from 'axios';

// 查询OSS对象存储列表
export function listOss(query: OssQuery): AxiosPromise<OssVO[]> {
  return request({
    url: '/resource/oss/list',
    method: 'get',
    params: query
  });
}

// 查询OSS对象基于id串
export function listByIds(ossId: string | number, type = 1): AxiosPromise<OssVO[]> {
  return request({
    url: '/resource/oss/listByIds/' + ossId + '?type=' + type,
    method: 'get'
  });
}

export function updateById(ossId: string | number, sortindex = 1): AxiosPromise<OssVO[]> {
  return request({
    url: '/resource/oss/update',
    method: 'put',
    params: { ossId: ossId, sortindex: sortindex }
  });
}

// 删除OSS对象存储
export function delOss(ossId: string | number | Array<string | number>) {
  return request({
    url: '/resource/oss/' + ossId,
    method: 'delete'
  });
}

export function listArchivesFileList(query: OssQuery): AxiosPromise<OssVO[]> {
  return request({
    url: '/resource/oss/allArchivesFileList',
    method: 'get',
    params: query
  });
}

export function getqiniuToken() {
  return request({
    url: '/resource/oss/qiniu/token',
    method: 'get'
  });
}

export function addfile(data: any) {
  return request({
    url: '/resource/oss/add',
    method: 'post',
    data: data
  });
}


